@@ -14,7 +14,7 @@ manova.gls <- function(object, test=c("Pillai", "Wilks", "Hotelling-Lawley", "Ro
   if(is.null(args[["parametric"]])) param <- TRUE else param <- args$parametric
   if(is.null(args[["permutation"]])) penalized <- NULL else penalized <- args$permutation
   if(is.null(args[["rhs"]])) rhs <- NULL else rhs <- args$rhs
-  if(is.null(args[["verbose"]])) verbose <- FALSE else verbose <- args$verbose
+  if(is.null(args[["verbose"]])) verbose <- TRUE else verbose <- args$verbose
   if(is.null(args[["P"]])) P <- NULL else P <- args$P
   
   # Performs the tests
@@ -232,7 +232,7 @@ manova.gls <- function(object, test=c("Pillai", "Wilks", "Hotelling-Lawley", "Ro
   
   
   if(penalized=="full"){
-    Dsqrt <- pruning(object$corrSt$phy, trans=FALSE, inv=FALSE)$sqrtM
+    Dsqrt <- .pruning_general(object$corrSt$phy, trans=FALSE, inv=FALSE)$sqrtM
     modelPerm <- object$call
     modelPerm$grid.search <- quote(FALSE)
     modelPerm$start <- quote(object$opt$par)
@@ -499,7 +499,7 @@ manova.gls <- function(object, test=c("Pillai", "Wilks", "Hotelling-Lawley", "Ro
   
   
   if(penalized=="full"){
-    Dsqrt <- pruning(object$corrSt$phy, trans=FALSE, inv=FALSE)$sqrtM
+    Dsqrt <- .pruning_general(object$corrSt$phy, trans=FALSE, inv=FALSE)$sqrtM
     modelPerm <- object$call
     modelPerm$grid.search <- quote(FALSE)
     modelPerm$start <- quote(object$opt$par)
@@ -962,13 +962,18 @@ effectsize <- function(x, ...){
             }
         })
         mult <- matrix(mult,nrow=1)
-        if(x$type=="glh") colnames(mult) = "contrast" else colnames(mult) = x$terms
+        if(x$type=="glh" | x$type=="glhrm"){
+            if(!is.null(rownames(x$L))) colnames(mult) = paste(rownames(x$L), "|") else colnames(mult) = "contrast"
+        }else{
+            colnames(mult) = x$terms
+        }
         rownames(mult) = row_names # paste("A(",x$test,")",sep = "")
     }else{
         
         # retrieve expectations and theoretical bounds
         Anull <- colMeans(x$nullstat)
         if(x$type=="III") s <- table(x$dims$assign) else s <- table(x$dims$assign)[-1L]
+        if(x$type=="glh" | x$type=="glhrm") s <- 1 # Overwrite the previous estimate as Df = 1 for each contrasts (i.e. rank of individual contrasts)
         
         switch(x$test,
         "Wilks"={
@@ -999,7 +1004,11 @@ effectsize <- function(x, ...){
         
         # We return the chance-corrected metrics. Should we return 0 when mult <0?
         mult <- matrix(mult, nrow=1)
-        if(x$type=="glh") colnames(mult) = "contrast" else colnames(mult) = x$terms
+        if(x$type=="glh" | x$type=="glhrm"){
+            if(!is.null(rownames(x$L))) colnames(mult) = paste(rownames(x$L), "|") else colnames(mult) = "contrast"
+        }else{
+            colnames(mult) = x$terms
+        }
         rownames(mult) = row_names #paste("Aperm.(",x$test,")",sep = "")
     }
     if(x$test=="Wilks") attr(adjusted, "tatsuoka") <- tatsuoka else attr(adjusted, "tatsuoka") <- FALSE
@@ -1016,6 +1025,7 @@ effectsize <- function(x, ...){
 
 pairwise.contrasts <- function(object, term=1, ...){
     if(object$contrasts[term]!="contr.treatment") stop("object fit must use dummy coding - see ?contr.treatment")
+    if(length(object$xlevels)==0) stop("contrasts tests only apply to factors - you must provide a list or a dataframe containing your data to mvgls/mvols")
     names_variables <- paste(names(object$xlevels[term]), object$xlevels[[term]], sep="")
     indice_predictor <- attr(object$variables$X,"dimnames")[[2]]%in%c("(Intercept)",names_variables)
     names_pred <- attr(object$variables$X,"dimnames")[[2]][indice_predictor]
@@ -1078,7 +1088,7 @@ pairwise.glh <- function(object, term=1, test=c("Pillai", "Wilks", "Hotelling-La
         
         summary_tests <- list(test=test, stat=permTests[2,], approxF=permTests[3,],
         Df=permTests[1,], NumDf=permTests[4,], DenDf=permTests[5,], pvalue=permTests[6,],  param=param, terms=terms,
-        dims=object$dims, adjust=p.adjust(permTests[6,], method = adjust), L=L)
+        dims=object$dims, adjust=p.adjust(permTests[6,], method = adjust), L=L, type="glh")
         
     }else{
         param = FALSE # we use permutation rather than parametric test
@@ -1100,9 +1110,12 @@ pairwise.glh <- function(object, term=1, test=c("Pillai", "Wilks", "Hotelling-La
         # statistic
         stats <- sapply(1:nb_contrasts, function(i) permTests[[i]]$observed)
         
+        # formating of the null distributions
+        permNulls <- sapply(permTests, function(x) x$simulated)
+        
         # retrieve the statistic
-        summary_tests <- list(test=test, stat=stats, pvalue=p_val, param=param, terms=terms, nperm=nperm, nullstat=permTests, dims=object$dims,
-        adjust=p.adjust(p_val, method = adjust), L=L)
+        summary_tests <- list(test=test, stat=stats, pvalue=p_val, param=param, terms=terms, nperm=nperm, nullstat=permNulls, dims=object$dims,
+        adjust=p.adjust(p_val, method = adjust), L=L, type="glh")
     }
     
     # retrieve results
